@@ -37,6 +37,9 @@ OC.L10N.register(
     "Remove account" : "Remover conto",
     "Delete" : "Deler",
     "Add" : "Adder",
+    "Tags" : "Etiquettas",
+    "Search" : "Cercar",
+    "Date" : "Date",
     "Enabled" : "Activate",
     "Custom" : "Personalisate",
     "Reset" : "Re-fixar",
@@ -46,7 +49,6 @@ OC.L10N.register(
     "Port" : "Porto",
     "Keyboard shortcut" : "Combination de claves",
     "Keyboard shortcuts" : "Combinationes de claves",
-    "Search" : "Cercar",
     "Refresh" : "Refrescar",
     "All" : "Tote",
     "Favorites" : "Favoritos",
