@@ -16,13 +16,15 @@ OC.L10N.register(
     "Select" : "Select",
     "Move" : "Move",
     "Create" : "បង្កើត",
+    "Comment" : "មតិ",
     "Choose" : "ជ្រើស",
-    "Favorites" : "Favorites",
     "Other" : "ផ្សេងៗ",
     "Reply" : "ឆ្លើយតប",
-    "Settings" : "ការកំណត់",
     "Delete" : "លុប",
     "Add" : "បញ្ចូល",
+    "Tags" : "ស្លាក",
+    "Search" : "Search",
+    "Date" : "កាលបរិច្ឆេទ",
     "Disabled" : "បាន​បិទ",
     "Enabled" : "បាន​បើក",
     "Remove" : "ដកចេញ",
@@ -30,9 +32,9 @@ OC.L10N.register(
     "User" : "User",
     "Host" : "ម៉ាស៊ីន​ផ្ទុក",
     "Port" : "ច្រក",
-    "Search" : "Search",
     "All" : "ទាំងអស់",
     "Drafts" : "ពង្រាង",
+    "Favorites" : "Favorites",
     "Inbox" : "ក្នុង​ប្រអប់សារ",
     "Junk" : "ព្រៃ",
     "Sent" : "ផ្ញើ",
