@@ -1,7 +1,6 @@
 OC.L10N.register(
     "mail",
     {
-    "Auto detect failed. Please use manual mode." : "Vetëzbulimi dështoi. Ju lutemi, përdorni metodën dorazi.",
     "Important" : "E rëndësishme",
     "Work" : "Punë",
     "Personal" : "Personale",
@@ -44,13 +43,15 @@ OC.L10N.register(
     "Edit tags" : "Përpunoni etiketa",
     "Move" : "Zhvendos",
     "More actions" : "Më tepër veprime ",
+    "Forward" : "Përpara",
     "All day" : "Gjithë ditën",
     "Create" : "Krijo",
+    "Comment" : "Koment",
+    "Accept" : "Prano",
+    "Decline" : "Refuzo",
     "Choose" : "Zgjidhni",
-    "Favorites" : "Favorites",
     "Other" : "Tjetër",
     "Reply" : "Përgjigju",
-    "Forward" : "Përpara",
     "Import into calendar" : "Importo në kalendar",
     "Download attachment" : "Shkarko bashkëlidhjen",
     "Save to Files" : "Ruaje te Skedarët",
@@ -58,22 +59,29 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "Zgjidhni një dosje ku të depozitohet bashkëngjitja",
     "Save all to Files" : "Ruaji të gjitha te Dosjet",
     "The images have been blocked to protect your privacy." : "Imazhet janë bllokuar për të mbrojtur privatësinë tuaj.",
-    "New message" : "Mesazh i ri",
-    "Settings" : "Konfigurimet",
     "Quota" : "Kuotë",
     "Saving" : "Duke u ruajtur!",
     "Remove account" : "Fshij llogarinë",
     "Mark all as read" : "Shënoji krejt si të lexuar",
     "Clear cache" : "Pastroje fshehtinën",
+    "New message" : "Mesazh i ri",
+    "Message" : "Mesazh",
     "Delete" : "Fshij",
     "Copy to clipboard" : "Kopjo në dërrasë ",
     "Add" : "Shto",
+    "Tags" : "Etiketat",
+    "Select tags" : "Përzgjidh etiketat",
+    "Clear" : "Pastro",
+    "Search" : "Kërko",
+    "Date" : "Data",
     "Disabled" : "I çaktivizuar",
     "Enabled" : "I aktivizuar",
     "Custom" : "E përshtatur",
     "Unset" : "E pavendosur",
     "Add tag" : "Shto etiketim",
     "Tag already exists" : "Etiketa ekziston",
+    "Mark as unread" : "Shënoje si të palexuar",
+    "Mark as read" : "Shënoje si të lexuar",
     "Remove" : "Hiq",
     "Reset" : "Rivendos",
     "General" : "Të përgjithshme",
@@ -87,12 +95,12 @@ OC.L10N.register(
     "Older message" : "Mesazhe më të vjetra",
     "Toggle star" : "Toggle star",
     "Toggle unread" : "Toggle i pa lexuar",
-    "Search" : "Kërko",
     "Refresh" : "Rifresko",
     "Connect your mail account" : "Lidhni llogarinë tuaj të postës elektronike",
     "All" : "Të gjithë",
     "Archive" : "Arkiva",
     "Drafts" : "Skica",
+    "Favorites" : "Favorites",
     "All inboxes" : "Krejt kutitë e postës",
     "Inbox" : "Inbox",
     "Junk" : "Të pavlera",
@@ -107,7 +115,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klikoni këtu nëse nuk ridrejtoheni automatikisht brenda disa sekondave",
     "Redirect" : "Ridrejtoje",
     "The link leads to %s" : "Lidhja shpie te %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Nëse s’doni ta vizitoni atë faqe, mund të ktheheni te <a href=\"%s\">Posta</a>.",
     "Continue to %s" : "Vazhdo te %s"
 },
 "nplurals=2; plural=(n != 1);");
