@@ -1,9 +1,7 @@
 OC.L10N.register(
     "mail",
     {
-    "Auto detect failed. Please use manual mode." : "自動偵測失敗。請使用手動模式。",
-    "Updating account failed: " : "更新賬號失敗：",
-    "Embedded message %s" : "內嵌郵件 %s",
+    "Embedded message %s" : "內嵌訊息 %s",
     "Important mail" : "重要郵件",
     "Unread mail" : "未讀郵件",
     "Important" : "重要",
@@ -14,10 +12,11 @@ OC.L10N.register(
     "Mails" : "郵件",
     "Mail" : "郵件",
     "💌 A mail app for Nextcloud" : "Nextcloud 的郵件應用程式",
-    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](https://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 的郵件應用程式**\n\n- **🚀 與其他 Nextcloud 應用程式整合！** 目前有聯絡人、日曆與檔案 – 還會有更多。\n- **📥 多組郵件賬號！** 私人與公司賬號？沒問題，而且有很好的統一收件匣。可連線到任何 IMAP 賬號。\n- **🔒 傳送與接收加密電子郵件！** 使用超棒的 [Mailvelope]（https://mailvelope.com）瀏覽器擴充套件。\n- **🙈 我們並未重新發明輪子！** 以超棒的 [Horde]（https://horde.org）函式庫為基礎。\n- **📬 想要自架郵件伺服器嗎？** 我們不用重新實作此動作，因為您可以設定 [Mail-in-a-Box]（https://mailinabox.email）！",
+    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](https://horde.org) libraries.\n- **📬 Want to host your own mail server?** We do not have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 的郵件應用程式**\n\n- **🚀 與其他 Nextcloud 應用程式整合！** 目前有聯絡人、日曆與檔案 – 還會有更多。\n- **📥 多組郵件賬號！** 私人與公司賬號？沒問題，而且有很好的統一收件匣。可連線到任何 IMAP 賬號。\n- **🔒 傳送與接收加密電子郵件！** 使用超棒的 [Mailvelope]（https://mailvelope.com）瀏覽器擴充套件。\n- **🙈 我們並未重新發明輪子！** 以超棒的 [Horde]（https://horde.org）函式庫為基礎。\n- **📬 想要自架郵件伺服器嗎？** 我們不用重新實作此動作，因為您可以設定 [Mail-in-a-Box]（https://mailinabox.email）！",
     "Drafts are saved in:" : "草稿儲存於：",
     "Sent messages are saved in:" : "已傳送的郵件儲存於：",
     "Deleted messages are moved in:" : "已刪除的郵件移動至：",
+    "Archived messages are moved in:" : "已封存的郵件移動至：",
     "Auto" : "自動",
     "Name" : "姓名",
     "Mail address" : "電郵地址",
@@ -43,6 +42,20 @@ OC.L10N.register(
     "Connecting" : "連線中",
     "Save" : "儲存",
     "Connect" : "連線",
+    "Looking up configuration" : "查找配置",
+    "Checking mail host connectivity" : "檢查郵件主機連接",
+    "Configuration discovery failed. Please use the manual settings" : "配置發現失敗。 請使用手動設置",
+    "Testing authentication" : "測試認證",
+    "Account created" : "賬戶已創建",
+    "Account updated" : "賬戶已更新",
+    "Changes saved" : "變更已保存",
+    "IMAP server is not reachable" : "IMAP 伺服器無法連線",
+    "SMTP server is not reachable" : "SMTP 伺服器無法連線",
+    "IMAP username or password is wrong" : "IMAP 用戶名或密碼錯誤",
+    "SMTP username or password is wrong" : "SMTP 用戶名或密碼錯誤",
+    "IMAP connection failed" : "IMAP 連線失敗",
+    "SMTP connection failed" : "SMTP 連線失敗",
+    "There was an error while setting up your account" : "設置您的帳戶時出錯。 ",
     "Account settings" : "賬號設定",
     "Change name" : "更改名稱",
     "Signature" : "簽名",
@@ -50,11 +63,14 @@ OC.L10N.register(
     "Writing mode" : "書寫模式",
     "Preferred writing mode for new messages and replies." : "新訊息和回覆的首選書寫模式。",
     "Default folders" : "默認資料夾",
-    "The folders to use for drafts, sent messages and deleted messages." : "用於存儲草稿，已發送郵件和已刪除郵件的資料夾。",
-    "Mail server" : "郵件伺服器",
-    "Sieve filter server" : "Sieve 過濾伺服器",
+    "The folders to use for drafts, sent messages, deleted messages and archived messages." : "用於存儲草稿，已發送郵件，已刪除郵件和已封存郵件的資料夾。",
+    "Autoresponder" : "自動回復程式",
+    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "自動回覆收到的訊息。如果有人向您發送多個訊息，此自動回覆最多每 4 天傳送一次。",
+    "Please connect to a sieve server first." : "請先連接到篩網伺服器。",
     "Sieve filter rules" : "Sieve 過濾規則",
     "Trusted senders" : "受信任的寄件人",
+    "Mail server" : "郵件伺服器",
+    "Sieve filter server" : "Sieve 過濾伺服器",
     "Update alias" : "更新别名",
     "Show update alias form" : "顯示更新別名表格",
     "Delete alias" : "删除别名",
@@ -63,11 +79,11 @@ OC.L10N.register(
     "Create alias" : "創建别名",
     "Cancel" : "取消",
     "Add mail account" : "添加電郵帳戶",
-    "Use Gravatar and favicon avatars" : "使用個人化大頭貼與網站圖示",
+    "Use Gravatar and favicon avatars" : "使用 Gravatar 和 favicon 虛擬化身圖示",
     "Register as application for mail links" : "註冊為處理郵件連結的應用程式",
     "Show keyboard shortcuts" : "顯示鍵盤快捷鍵",
     "Looking for a way to encrypt your emails?" : "正在尋找加密電子郵件的方法嗎？",
-    "Install Mailvelope browser extension" : "安裝 Mailvelope 瀏覽器擴充套件",
+    "Install Mailvelope browser extension here" : "在此安裝 Mailvelope 瀏覽器擴充套件",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "允許應用程式蒐集關於您互動的資料。以此資料為基礎，應用程式將會適應您的偏好設定。資料將只會儲存在本機。",
     "Put my text to the bottom of a reply instead of on top of it." : "將我的文字放在回覆的底部而不是頂部。",
     "Automatically classify importance of new email" : "自動分類新郵件的重要性",
@@ -94,6 +110,7 @@ OC.L10N.register(
     "Add attachment from Files" : "從雲端檔案中加入附件",
     "Send later" : "稍後傳送",
     "Enable formatting" : "啟用格式",
+    "Disable formatting" : "停用格式",
     "Request a read receipt" : "索取讀取回條",
     "Encrypt message with Mailvelope" : "使用 Mailvelope 加密郵件",
     "Send now" : "立即傳送",
@@ -118,17 +135,22 @@ OC.L10N.register(
     "Message {id} could not be found" : "找不到郵件 {id}",
     "No sent mailbox configured. Please pick one in the account settings." : "未設定寄件備份信箱。請在賬號設定中選取。",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "您正在嘗試發送給“收件人”和/或“抄送”中的許多收件人。考慮使用密件抄送（Bcc）隱藏收件人地址。",
-    "Uploading {percent}% …" : "正在上傳 {percent}%……",
+    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "任何現有格式（例如粗體、斜體、下劃線或內嵌圖像）都將被刪除。",
+    "Turn off formatting" : "停用格式",
+    "Turn off and remove formatting" : "停用並刪除格式",
+    "Keep formatting" : "保持格式",
     "Choose a file to add as attachment" : "選擇要作為附件的檔案",
     "Choose a file to share as a link" : "選擇要作為連結分享的檔案",
+    "_{count} attachment_::_{count} attachments_" : ["{count} 個附件"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["附件超過了允許的附件大小 {size}。請透過連結分享檔案。"],
     "No message found yet" : "找不到訊息",
     "Set up an account" : "設定賬號",
     "Plain text" : "純文字",
     "Rich text" : "RTF",
     "No messages in this mailbox" : "此信箱中沒有郵件",
-    "No messages" : "沒有郵件",
+    "Messages marked as important will show up here" : "標記為重要的訊息將在此處顯示",
     "Draft: " : "草稿：",
+    "This message is unread" : "此訊息未讀",
     "Unfavorite" : "取消我的最愛",
     "Favorite" : "我的最愛",
     "Unread" : "未讀",
@@ -141,14 +163,18 @@ OC.L10N.register(
     "Edit tags" : "編輯標籤",
     "Move" : "移動",
     "Move thread" : "移動主題",
-    "More actions" : "更多操作",
+    "Archive thread" : "封存主題",
     "Delete thread" : "刪除主題",
+    "More actions" : "更多操作",
     "Edit as new message" : "以新郵件的方式編輯",
     "Create event" : "創建活動",
+    "Download message" : "下載訊息",
     "Blind copy recipients only" : "僅密件副本收件者",
     "No subject" : "無題",
     "No trash mailbox configured" : "未設定垃圾信箱",
     "Could not delete message" : "無法刪除郵件",
+    "Could not archive message" : "無法封存郵件",
+    "Forward" : "轉寄",
     "Load more" : "載入更多",
     "_Mark {number} unread_::_Mark {number} unread_" : ["將 {number} 標記為未讀"],
     "_Mark {number} read_::_Mark {number} read_" : ["將 {number} 標記為已讀"],
@@ -165,26 +191,41 @@ OC.L10N.register(
     "Create" : "創建",
     "Event created" : "活動已建立",
     "Could not create event" : "無法建立活動",
+    "You accepted this invitation" : "您}接受了此邀请。",
+    "You tentatively accepted this invitation" : "你暫時接受了此邀請",
+    "You declined this invitation" : "您婉拒了拒此邀請",
+    "You already reacted to this invitation" : "您已對此邀請作出反應",
+    "You have been invited to an event" : "您已受邀參加活動",
+    "This event was cancelled" : "此活動已取消",
+    "Save to" : "保存到",
+    "Comment" : "留言",
+    "Accept" : "接受",
+    "Decline" : "婉拒",
+    "Tentatively accept" : "暫時接受",
+    "More options" : "更多選項",
+    "This event is in the past." : "此活動已經過去了。",
+    "This event was updated" : "此活動已更新",
+    "{attendeeName} accepted your invitation" : "{attendeeName} 已接受您的邀請",
+    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} 暫時接受了您的邀請",
+    "{attendeeName} declined your invitation" : "{attendeeName} 已婉拒您的邀請",
+    "{attendeeName} reacted to your invitation" : "{attendeeName} 已對您的邀請作出反應",
     "Could not open mailbox" : "無法開啟信箱",
     "Loading messages …" : "正在載入訊息 ...",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "正在索引您的郵件。對於較大的信箱來說，這可能需要較長的時間。",
     "Choose target mailbox" : "選擇目標信箱",
     "No more submailboxes in here" : "這裡沒有更多子信箱",
     "Choose" : "選擇",
-    "Important and unread" : "重要與未讀",
     "Important info" : "重要資訊",
-    "Favorites" : "我的最愛",
     "Other" : "其他",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "郵件將會以您與其互動或標記為重要的郵件為基礎來自動標記重要郵件。ㄧ開始，您可以能必須手動教導系統哪些是重要郵件，然後它就會與時俱進。",
     "The sender of this message has asked to be notified when you read this message." : "此郵件的發件人已要求閱讀確認。",
     "Notify the sender" : "通知寄件人",
     "You sent a read confirmation to the sender of this message." : "你已將讀取回條傳送給此郵件的寄件人。",
     "Could not send mdn" : "無法傳送 mdn",
+    "Reply all" : "回覆全部",
     "Reply" : "回覆",
     "Reply to sender only" : "僅回覆寄件人",
-    "Forward" : "轉寄",
     "Move message" : "移動訊息",
-    "Delete message" : "刪除訊息",
     "Forward message as attachment" : "將訊息作為附件轉發",
     "View source" : "檢視原始碼",
     "Download thread data for debugging" : "下載郵件串的資料以供除錯",
@@ -196,12 +237,14 @@ OC.L10N.register(
     "Unnamed" : "未命名",
     "Embedded message" : "內嵌郵件",
     "Choose a folder to store the attachment in" : "選擇一個資料夾來存放附件",
+    "View fewer attachments" : "檢視較少附件",
     "Save all to Files" : "全部儲存至檔案",
     "Download Zip" : "下載 Zip",
     "Choose a folder to store the attachments in" : "選擇一個資料夾來存放附件",
+    "_View {count} more attachment_::_View {count} more attachments_" : ["檢視另外 {count} 個附件"],
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "此郵件使用 PGP 加密。安裝 Mailvelope 來解密。",
     "The images have been blocked to protect your privacy." : "為維護您的隱私，圖片將不會被載入。",
-    "Show" : "顯示",
+    "Show images" : "顯示圖像",
     "Show images temporarily" : "暫時顯示圖像",
     "Always show images from {sender}" : "一律顯示來自 {sender} 的圖像",
     "Always show images from {domain}" : "一律顯示來自 {domain} 的圖像",
@@ -210,8 +253,7 @@ OC.L10N.register(
     "Moving" : "正在移動",
     "Moving thread" : "移動主題",
     "Moving message" : "移動訊息",
-    "New message" : "新郵件",
-    "Settings" : "設定",
+    "Mail settings" : "電郵設定",
     "Quota" : "用量",
     "Show only subscribed mailboxes" : "僅顯示已訂閱的信箱",
     "Add mailbox" : "新增信箱",
@@ -236,21 +278,33 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "如果遇到同步問題，請清除近端緩存資料。",
     "Subscribed" : "已訂閱",
     "Sync in background" : "背景同步",
+    "Clear mailbox" : "清除信箱",
     "Delete mailbox" : "刪除信箱",
+    "All messages in mailbox will be deleted." : "郵箱中的所有訊息都將被刪除。",
+    "Clear mailbox {name}" : "清除信箱 {name}",
     "The mailbox and all messages in it will be deleted." : "信箱與其中的所有郵件都會被刪除。",
     "Delete mailbox {name}" : "刪除信箱 {name}",
     "An error occurred, unable to rename the mailbox." : "遇到錯誤，無法重新命名信箱。",
     "_{total} message_::_{total} messages_" : ["{total} 封郵件"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} 中的 {unread} 未讀"],
     "Outbox" : "發件箱",
+    "New message" : "新郵件",
     "Edit message" : "編輯訊息",
     "Draft" : "草稿",
     "Message discarded" : "訊息已刪除",
     "Could not discard message" : "無法掉棄訊息",
     "No message selected" : "未選擇郵件",
+    "Autoresponder off" : "關閉自動回復程式",
+    "Autoresponder on" : "開啟自動回復程式",
+    "First day" : "第一天",
+    "Last day (optional)" : "最後一天（可選）",
+    "Message" : "訊息",
+    "Oh Snap!" : "哎呀！",
+    "Save autoresponder" : "保存自動回復程式",
     "Could not open outbox" : "無法開啟發件箱",
     "Pending or not sent messages will show up here" : "待處理或未傳送的訊息將在此處顯示",
     "Delete" : "刪除",
+    "Message could not be sent" : "無法傳送訊息",
     "Message deleted" : "訊息已刪除",
     "Contacts with this address" : "具有此地址的聯絡人",
     "Add to Contact" : "新增聯絡人",
@@ -258,6 +312,11 @@ OC.L10N.register(
     "Copy to clipboard" : "複製到剪貼板",
     "Contact name …" : "聯絡人名稱 ...",
     "Add" : "新增",
+    "Tags" : "標籤",
+    "Select tags" : "選擇標籤",
+    "Clear" : "清除",
+    "Search" : "搜尋",
+    "Date" : "日期",
     "Disabled" : "停用",
     "Enabled" : "啟用",
     "Sieve Host" : "Sieve 主機",
@@ -268,12 +327,12 @@ OC.L10N.register(
     "Custom" : "自訂",
     "Sieve User" : "Sieve 賬戶",
     "Sieve Password" : "Sieve 密碼",
-    "Oh Snap!" : "哎呀！",
     "Save sieve settings" : "保存 Sieve 設置",
     "Save sieve script" : "保存 Sieve 腳本語言（script）",
     "Signature …" : "簽名……",
-    "Place signature above quoted text" : "將簽名置於引用文字上方",
+    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "您的簽名大於 2 MB。這可能會影響編輯器的性能。",
     "Save signature" : "儲存簽名",
+    "Place signature above quoted text" : "將簽名置於引用文字上方",
     "Add default tags" : "添加默認標籤",
     "Rename tag" : "重新命名標籤",
     "Saving new tag name …" : "正在儲存新的標籤名稱……",
@@ -281,16 +340,25 @@ OC.L10N.register(
     "Unset" : "解除設置",
     "Add tag" : "添加標籤",
     "Saving tag …" : "標籤儲存中 ...",
+    "Tag name is a hidden system tag" : "標籤名稱是隱藏的系統標籤",
     "Tag already exists" : "標籤已經存在",
     "An error occurred, unable to create the tag." : "發生錯誤，無法建立標籤。",
     "An error occurred, unable to rename the tag." : "發生錯誤，無法重新命名標籤。",
     "Could not load your message thread" : "無法載入您的郵件串",
+    "Mark as unfavorite" : "取消標記我的最愛",
+    "Mark as favorite" : "標記為我的最愛",
+    "Mark as unread" : "標為未讀",
+    "Mark as read" : "標為已讀",
+    "Archive message" : "封存郵件",
+    "Delete message" : "刪除訊息",
     "Not found" : "找不到",
     "Remove" : "移除",
     "No senders are trusted at the moment." : "當前沒有發件人是受信任的",
     "Could not remove trusted sender {sender}" : "無法刪除受信任的發件人 {sender}",
     "individual" : "個人",
     "domain" : "網域名稱",
+    "(organizer)" : "（主辦人）",
+    "Untitled event" : "無標題活動",
     "Import into {calendar}" : "已匯入至 {calendar}",
     "Event imported into {calendar}" : "活動已匯入至 {calendar}",
     "Airplane" : "飛機",
@@ -314,6 +382,8 @@ OC.L10N.register(
     "Provisioning Configurations" : "帳號設定",
     "Add new config" : "添加新配置",
     "Provision all accounts" : "配置所有賬戶",
+    "Allow additional mail accounts" : "允許附加的電郵帳戶",
+    "Allow additional Mail accounts from User Settings" : "從用戶設置允許附加的電郵帳戶",
     "Anti Spam Service" : "反垃圾郵件服務",
     "You can set up an anti spam service email address here." : "您可以在此設定反垃圾郵件服務的電郵地址。",
     "Any email that is marked as spam will be sent to the anti spam service." : "任何被標記為垃圾郵件的電郵會被傳送到反垃圾郵件服務。",
@@ -369,19 +439,14 @@ OC.L10N.register(
     "Older message" : "較舊的信件",
     "Toggle star" : "加上／移除星號",
     "Toggle unread" : "標示未讀／已讀",
-    "Search" : "搜尋",
     "Refresh" : "重新整理",
     "Connect your mail account" : "連結您的郵件賬號",
-    "Auto detect failed. Please try manual mode." : "自動偵測失敗。請使用手動模式。",
-    "Manual config failed. IMAP server is not reachable." : "手動配置失敗。無法訪問 IMAP 服務器。",
-    "Manual config failed. SMTP server is not reachable." : "手動配置失敗。無法訪問 SMTP 服務器。",
-    "Manual config failed. IMAP username or password is wrong." : "手動配置失敗。IMAP 用戶名或密碼錯誤。",
-    "Manual config failed. SMTP username or password is wrong." : "手動配置失敗。SMTP 用戶名或密碼錯誤。",
-    "There was an error while setting up your account. Please try again." : "設置您的帳戶時出錯。 請再試一次。",
+    "To add a mail account, please contact your administrator." : "要添加電郵帳戶，請聯繫您的管理員。",
     "Itinerary for {type} is not supported yet" : "目前尚未支援 {type} 的行程",
     "All" : "全部",
     "Archive" : "封存",
     "Drafts" : "草稿",
+    "Favorites" : "我的最愛",
     "Priority inbox" : "優先收件匣",
     "All inboxes" : "所有收件匣",
     "Inbox" : "收件匣",
@@ -405,7 +470,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "如果未在幾秒內重新導向，請點擊此處。",
     "Redirect" : "重新導向",
     "The link leads to %s" : "該連結導向至 %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "若不想造訪該頁，您可以回到<a href=\"%s\">郵件</a>。",
+    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "若不想造訪該頁，您可以回到<a href=\"%s\">Mail</a>。",
     "Continue to %s" : "前往 %s"
 },
 "nplurals=1; plural=0;");
